@@ -25,11 +25,11 @@ Test2::Aggregate - Aggregate tests
 
 =head1 VERSION
 
-Version 0.10_02
+Version 0.10_03
 
 =cut
 
-our $VERSION = '0.10_02';
+our $VERSION = '0.10_03';
 
 
 =head1 DESCRIPTION
@@ -56,6 +56,7 @@ that do not work.
     my $stats = Test2::Aggregate::run_tests(
         dirs          => \@dirs,              # optional if lists defined
         lists         => \@lists,             # optional if dirs defined
+        excludes      => \@exclude_regexes,   # optional
         root          => '/testroot/',        # optional
         load_modules  => \@modules,           # optional
         package       => 0,                   # optional
@@ -98,6 +99,10 @@ true) will be processed and tests run in order specified.
 Arrayref of flat files from which each line will be pushed to C<dirs>
 (so they have a lower precedence - note C<root> still applies).
 
+=item * C<excludes> (optional)
+
+Arrayref of regexes to filter out tests that you want excluded.
+
 =item * C<root> (optional)
 
 If defined, must be a valid root directory that will prefix all C<dirs> and
@@ -125,9 +130,9 @@ warning if C<test_warnings> is also set).
 
 =item * C<unique> (optional)
 
-Since v0.11 duplicate tests are by default removed from the running list as that
-could mess up the statistics output. You can still set it to a false value to allow
-duplicate tests to be in the list.
+Since v0.11, duplicate tests are by default removed from the running list as that
+could mess up the stats output. You can still set it to a false value to allow
+duplicate tests in the list.
 
 =item * C<shuffle> (optional)
 
@@ -206,21 +211,14 @@ sub run_tests {
             if @dirs;
     }
 
-    $args{unique} = 1       if !defined $args{unique};
-    @tests = _uniq(@tests)  if $args{unique};
-    @tests = reverse @tests if $args{reverse};
+    $args{unique} = 1 unless defined $args{unique};
+    $args{repeat} ||= 1;
 
-    if ($args{shuffle}) {
-        require List::Util;
-        @tests = List::Util::shuffle @tests;
-    } elsif ($args{sort}) {
-        @tests = sort @tests;
-    }
+    _process_run_order(\@tests, \%args);
 
     my @stack = caller();
     $args{caller} = $stack[1] || 'aggregate';
     $args{caller} =~ s#^.*?([^/]+)$#$1#;
-    $args{repeat} ||= 1;
 
     my $warnings = [];
     if ($args{repeat} < 0) {
@@ -258,6 +256,25 @@ sub run_tests {
     return $args{stats};
 }
 
+sub _process_run_order {
+    my $tests = shift;
+    my $args  = shift;
+
+    foreach my $regex (@{$args->{excludes}}) {
+        @$tests = grep(!/$regex/, @$tests);
+    }
+
+    @$tests = _uniq(@$tests)  if $args->{unique};
+    @$tests = reverse @$tests if $args->{reverse};
+
+    if ($args->{shuffle}) {
+        require List::Util;
+        @$tests = List::Util::shuffle @$tests;
+    } elsif ($args->{sort}) {
+        @$tests = sort @$tests;
+    }
+}
+
 sub _process_warnings {
     my $warnings = shift;
     my $args     = shift;
@@ -286,15 +303,13 @@ sub _run_tests {
 
     for my $i (1 .. $repeat) {
         my $iter = $repeat > 1 ? "Iter: $i/$repeat - " : '';
-        my $count = 0;
+        my $count = 1;
         foreach my $test (@$tests) {
-            my $start;
 
             warn "$test->Test2::Aggregate\n" if $args->{test_warnings};
 
-            $count++;
-            $stats{$test}{test_no} ||= $count;
-            $start = Time::HiRes::time() if $args->{stats_output};
+            $stats{$test}{test_no} = $count unless $stats{$test}{test_no};
+            my $start = Time::HiRes::time() if $args->{stats_output};
             $stats{$test}{timestamp} = _timestamp();
 
             my $result = subtest $iter. "Running test $test" => sub {
@@ -308,6 +323,7 @@ sub _run_tests {
             $stats{$test}{time} += (Time::HiRes::time() - $start)/$repeat
                 if $args->{stats_output};
             $stats{$test}{pass_perc} += $result ? 100/$repeat : 0;
+            $count++;
         }
     }
 
